//##generation header##CodeWorker##v1.37##12dec2002 15:34:45##"Popeye and Olive"
package tiny;

public class Planet {
	// attributes:
	private  _diameter = null;

	//constructor:
	public () {
	}

	// accessors:
	public  getDIAMETER() { return _diameter; }
	public void setDIAMETER( diameter) { _diameter = diameter; }
//##protect##"Methods"
//##protect##"Methods"
}
