BODY
{
    FONT-SIZE: 80%;
    MARGIN: 2px 0px 0px 3px;
    COLOR: #000000;
    BACKGROUND-COLOR: #eeeedd
}
BODY
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
P
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
P.center
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif;
	TEXT-ALIGN: center
}
H1
{
    COLOR: #900b09;
    FONT-WEIGHT: bold;
    FONT-SIZE: 300%;
    FONT-FAMILY: "Courier New",monospace;
    TEXT-ALIGN: center
}
H2
{
    FONT-SIZE: 150%;
    FONT-FAMILY: verdana,helvetica,arial,sans-serif;
    TEXT-ALIGN: center
}
H3
{
    FONT-SIZE: 120%;
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
H4
{
    FONT-SIZE: 100%
}
H5
{
    FONT-SIZE: 90%
}
H6
{
    FONT-SIZE: 80%
}
TABLE
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
TD
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
TH
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
UL
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
OL
{
    FONT-FAMILY: verdana,helvetica,arial,sans-serif
}
TABLE
{
    FONT-SIZE: 100%
}
INPUT
{
    FONT-SIZE: 100%
}
TABLE.ex
{
    FONT-SIZE: 100%;
    COLOR: #000000;
    BACKGROUND-COLOR: #eeeedd
}
TABLE.db
{
    FONT-SIZE: 100%;
    COLOR: #000000;
    BACKGROUND-COLOR: #ffffff
}
TH.db
{
    COLOR: #000000;
    BACKGROUND-COLOR: #eeeedd
}
DIV
{
    WIDTH: 100%
}

TD.right
{
    COLOR: #000000;
    BACKGROUND-COLOR: #ffffff
}
TD.links
{
    BACKGROUND-COLOR: #f2f2e0
}
TD.content
{
    BACKGROUND-COLOR: #FFFFFF;
    TEXT-ALIGN: justify
}
TD.company
{
    BACKGROUND-COLOR: #F8F8F0;
	FONT-WEIGHT: bold;
    TEXT-ALIGN: center
}
TD.role
{
    BACKGROUND-COLOR: #F4FAFA;
	FONT-STYLE: italic
}
TD.changes
{
    BACKGROUND-COLOR: #F4FAFA;
	FONT-WEIGHT: bold;
	FONT-STYLE: italic;
    TEXT-ALIGN: center
}
TD.deprecated
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
TD.red
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
TD.title
{
    COLOR: #900b09;
    FONT-WEIGHT: bold;
    FONT-SIZE: 200%;
    TEXT-ALIGN: center
}
TD.license
{
    COLOR: #0000FF;
	FONT-WEIGHT: bold;
    BACKGROUND-COLOR: transparent
}
P.red
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
P.intro
{
    MARGIN-TOP: 10px;
    FONT-WEIGHT: bold;
    FONT-SIZE: 100%;
    COLOR: #000000;
    BACKGROUND-COLOR: transparent
}
P.introcenter
{
    FONT-SIZE: 110%;
    COLOR: #8b4513;
    BACKGROUND-COLOR: transparent;
    TEXT-ALIGN: center
}
PRE
{
    FONT-SIZE: 110%;
    MARGIN-BOTTOM: 0px;
    MARGIN-LEFT: 0px;
    FONT-FAMILY: "Courier New",monospace
}
SPAN.blue
{
    COLOR: #00008b;
    BACKGROUND-COLOR: transparent
}
SPAN.red
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
SPAN.ieonly
{
    FONT-SIZE: 70%;
    COLOR: #000080;
    BACKGROUND-COLOR: transparent
}
SPAN.t
{
    FONT-SIZE: 80%;
    COLOR: #0033cc;
    BACKGROUND-COLOR: transparent
}
IMG.float
{
    FLOAT: left
}
TABLE.front
{
    COLOR: #000000;
    BACKGROUND-COLOR: #8b4513
}
TH.front
{
    COLOR: #ffffff;
    BACKGROUND-COLOR: #900b08
}
TD.front
{
    COLOR: #000000;
    BACKGROUND-COLOR: #eeeedd
}
A.nounderline
{
    TEXT-DECORATION: none
}
A:link
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent
}
A:visited
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent
}
A:active
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
A:hover
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
A.left:link
{
    COLOR: blue;
    FONT-WEIGHT: bold;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: none
}
A.left:visited
{
    COLOR: blue;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: none
}
A.left:hover
{
    COLOR: #900b09;
    FONT-WEIGHT: bold;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: underline
}
A.left:active
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: underline
}
ma.right:link
{
    COLOR: black;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: none
}
ma.right:visited
{
    COLOR: black;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: none
}
ma.right:hover
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: underline
}
ma.right:active
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent;
    TEXT-DECORATION: underline
}
A.red:link
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent
}
A.red:visited
{
    COLOR: #900b09;
    BACKGROUND-COLOR: transparent
}
A.red:active
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
A.red:hover
{
    COLOR: #ff0000;
    BACKGROUND-COLOR: transparent
}
.CodeWorker
{
    COLOR: #900b09;
    FONT-WEIGHT: bold;
    FONT-FAMILY: "Courier New",monospace
}
.Verbatim
{
    FONT-FAMILY: "Courier New",monospace;
    BACKGROUND-COLOR: white
}
.AllTT
{
    FONT-FAMILY: "Courier New",monospace;
    BACKGROUND-COLOR: white
}
BODY.TOC
{
    FONT-SIZE: 60%;
    MARGIN: 2px 0px 0px 3px;
    BACKGROUND-COLOR: #f2f2e0
}
BODY.index
{
    FONT-SIZE: 60%;
    MARGIN: 2px 0px 0px 3px;
    BACKGROUND-COLOR: #f2f2e0
}
